@@ -30,8 +30,10 @@ class Client:
         )
         return self.__handle_response(response, "Failed to create mediafile", "text")
 
-    def create_mediafile_with_filename(self, filename):
+    def create_mediafile_with_filename(self, filename, institution_id=None):
         data = {"filename": filename, "type": "mediafile"}
+        if institution_id:
+            data.update({"metadata": [{"key": "institution", "value": institution_id}]})
         req = requests.post(
             f"{self.elody_collection_url}/mediafiles",
             json=data,
@@ -54,10 +56,17 @@ class Client:
         return req.text.strip().replace('"', "")
 
     def __get_upload_location(
-        self, entity_id, filename, is_public=True, identifiers=None
+        self,
+        entity_id,
+        filename,
+        is_public=True,
+        identifiers=None,
+        mediafile_object=None,
     ):
         if not identifiers:
             identifiers = list()
+        if not mediafile_object:
+            mediafile_object = dict()
         metadata = []
         if is_public:
             metadata = [
@@ -67,9 +76,12 @@ class Client:
                 }
             ]
         mediafile = {
-            "filename": filename,
-            "metadata": metadata,
-            "identifiers": identifiers,
+            **{
+                "filename": filename,
+                "metadata": metadata,
+                "identifiers": identifiers,
+            },
+            **mediafile_object,
         }
         return self.__create_mediafile(entity_id, mediafile)
 
@@ -146,11 +158,16 @@ class Client:
         response = requests.get(url, headers=self.headers, proxies=self.proxies)
         return self.__handle_response(response, "Failed to get object")
 
-    def update_object(self, collection, identifier, payload):
+    def update_object(self, collection, identifier, payload, overwrite=True):
         url = f"{self.elody_collection_url}/{collection}/{identifier}"
-        response = requests.put(
-            url, json=payload, headers=self.headers, proxies=self.proxies
-        )
+        if overwrite:
+            response = requests.put(
+                url, json=payload, headers=self.headers, proxies=self.proxies
+            )
+        else:
+            response = requests.patch(
+                url, json=payload, headers=self.headers, proxies=self.proxies
+            )
         return self.__handle_response(response, "Failed to update object")
 
     def update_object_relations(self, collection, identifier, payload):
@@ -167,13 +184,14 @@ class Client:
         file_url,
         identifiers=None,
         upload_location_replace_map=None,
+        mediafile_object=None,
     ):
         if not identifiers:
             identifiers = list()
         if not upload_location_replace_map:
             upload_location_replace_map = dict()
         upload_location = self.__get_upload_location(
-            entity_id, filename, True, identifiers
+            entity_id, filename, True, identifiers, mediafile_object
         )
         for current_location, new_location in upload_location_replace_map.items():
             upload_location = upload_location.replace(current_location, new_location)
