@@ -2,7 +2,7 @@ import elody.util as util
 import json
 import os
 
-from elody.policies.permission_handler import set_permissions
+from apscheduler.triggers.cron import CronTrigger
 from importlib import import_module
 from inuits_policy_based_auth.exceptions import (
     PolicyFactoryException,
@@ -17,9 +17,30 @@ def load_apps(flask_app, logger):
             flask_app.register_blueprint(api_bp)
 
 
+def load_jobs(scheduler, logger):
+    apps = util.read_json_as_dict(os.getenv("APPS_MANIFEST"), logger)
+    for app in apps:
+        for job, job_properties in apps[app].get("jobs", {}).items():
+            try:
+                job_class = __get_class_from_module(
+                    import_module(f"apps.{app}.cron_jobs.{job}")
+                )
+                scheduler.add_job(
+                    job_class(),
+                    CronTrigger.from_crontab(
+                        job_properties.get("expression", "0 0 * * *")
+                    ),
+                )
+            except ModuleNotFoundError:
+                pass
+
+
 def load_policies(policy_factory, logger, permissions={}):
     if permissions:
+        from elody.policies.permission_handler import set_permissions
+
         set_permissions(permissions)
+
     apps = util.read_json_as_dict(os.getenv("APPS_MANIFEST", ""), logger)
     for app in apps:
         try:
@@ -67,11 +88,15 @@ def __get_class(app, auth_type, policy_module_name):
             pass
     else:
         raise ModuleNotFoundError(f"Policy {policy_module_name} not found")
-    policy_class_name = module.__name__.split(".")[-1].title().replace("_", "")
-    policy = getattr(module, policy_class_name)
+    policy = __get_class_from_module(module)
     return policy
 
 
+def __get_class_from_module(module):
+    class_name = module.__name__.split(".")[-1].title().replace("_", "")
+    return getattr(module, class_name)
+
+
 def __instantiate_authentication_policy(policy_module_name, policy, logger):
     allow_anonymous_users = os.getenv("ALLOW_ANONYMOUS_USERS", False) in [
         "True",
