@@ -1,9 +1,10 @@
 import re as regex
 
 from flask import Request
+from flask_restful import abort
 from storage.storagemanager import StorageManager  # pyright: ignore
 from elody.util import get_item_metadata_value
-from elody.exceptions import NotFoundException
+from elody.exceptions import NotFoundException, NoTenantException
 
 
 class TenantIdResolver:
@@ -37,6 +38,8 @@ class TenantIdResolver:
             tenant_id = endpoint().get_tenant_id(request)
             if tenant_id != None:
                 relations = user.get("relations", [])
+                if len(relations) < 1:
+                    raise NoTenantException(f"User is not attached to a tenant")
                 has_tenant_relation = any(
                     relation.get("type") == "hasTenant"
                     and relation.get("key") == tenant_id
@@ -77,6 +80,9 @@ class BaseRequest:
             "share_link"
             # TODO Mediafile should have a link to an asset
             "mediafile",
+            "savedSearch",
+            "original_data",
+            "user",
         ]
 
     def _get_tenant_id_from_entity(self, entity_id):
@@ -85,7 +91,7 @@ class BaseRequest:
         )
         entity = self.storage.get_item_from_collection_by_id("entities", entity_id)
         if not entity:
-            raise NotFoundException(f"The asset with id {entity_id} doesn't exists")
+            abort(404, message=f"Item with id {entity_id} doesn't exist")
         type = entity.get("type")
         if type in self.global_types:
             return "tenant:super"
@@ -106,7 +112,7 @@ class BaseRequest:
 
         if entity and get_item_metadata_value(entity, "institution"):
             return f"tenant:{get_item_metadata_value(entity, 'institution')}"
-        raise Exception("Entity has no tenant, and is suppose to have one.")
+        abort(400, message="Entity has no tenant, and is suppose to have one.")
 
     def _get_tenant_id_from_mediafile(self, mediafile_id):
         mediafile_relations = self.storage.get_collection_item_relations(
@@ -123,6 +129,10 @@ class BaseRequest:
             return "tenant:super"
         if item.get("type") in self.global_types or item.get("type") == "institution":
             return "tenant:super"
+        if item.get("type") == "asset":
+            for relation in item.get("relations", []):
+                if relation.get("type") in ["hasArchesLink"]:
+                    return "tenant:super"
         institution_id = get_item_metadata_value(item, "institution")
         if not institution_id:
             for relation in item.get("relations", []):
@@ -130,7 +140,7 @@ class BaseRequest:
                     institution_id = relation.get("key")
         if institution_id:
             return f"tenant:{institution_id}"
-        raise Exception(f"Item in body doesn't have an institution.")
+        abort(400, message="Item in body doesn't have an institution.")
 
 
 class EntityGetRequest(BaseRequest):
